ToolButton class

A button under the navigation bar to help the user write code.

Constructors

ToolButton({required void press(), IconData? icon, String? symbol})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ IconData?
The icon to display on that button in case there is no Unicode character for it.
getter/setter pair
press ↔ void Function()
The function to execute when pressing the tool button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol ↔ String?
Simple Unicode characters to represent what the button's going to do. If there is no character able to describe its role, then use icon.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited